#include "gp2x_utils.h"

/*
    GP2X_BUTTON_LEFT   = SDLK_LEFT
    GP2X_BUTTON_RIGHT  = SDLK_RIGHT
    GP2X_BUTTON_UP     = SDLK_UP
    GP2X_BUTTON_DOWN   = SDLK_DOWN

    GP2X_BUTTON_L      = SDLK_INSERT - prev
    GP2X_BUTTON_R      = SDLK_RETURN - next

    GP2X_BUTTON_A      = SDLK_END - zoom
    GP2X_BUTTON_B      = SDLK_RETURN - next
    GP2X_BUTTON_X      = SDLK_PAGEUP
    GP2X_BUTTON_Y      = SDLK_PAGEDOWN

    GP2X_BUTTON_SELECT = SDLK_HOME - thumbnails
    GP2X_BUTTON_START  = SDLK_ESCAPE - exit
 */


SDL_Joystick* p_gp2x_joystick = NULL;
SDL_Event     gp2x_event;

int           i_ret;


int GP2X_JoystickInit( void )
{
    p_gp2x_joystick = SDL_JoystickOpen( 0 );

    return ( p_gp2x_joystick == NULL ) ? -1 : 0;
}

void GP2X_JoystickUninit( void )
{
    if( p_gp2x_joystick != NULL )
    {
        SDL_JoystickClose( p_gp2x_joystick );
        p_gp2x_joystick = NULL;
    }
}

int GP2X_JoystickEvents( SDL_Event *e )
{
    i_ret = 0;
    switch( e->type )
    {
        case SDL_JOYBUTTONDOWN:
            i_ret = 1;
            switch( e->jbutton.button )
            {
                case GP2X_BUTTON_LEFT:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_LEFT;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_RIGHT:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_RIGHT;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_UP:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_UP;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_DOWN:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_DOWN;
                    SDL_PushEvent( &gp2x_event );
                    break;
/*
                case GP2X_BUTTON_UPLEFT:
                case GP2X_BUTTON_UPRIGHT:
                case GP2X_BUTTON_DOWNLEFT:
                case GP2X_BUTTON_DOWNRIGHT:
                    break;
*/
                case GP2X_BUTTON_L:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_INSERT;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_R:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_RETURN;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_A:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_END;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_B:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_RETURN;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_X:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_PAGEUP;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_Y:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_PAGEDOWN;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_SELECT:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_HOME;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_START:
                    gp2x_event.type = SDL_KEYDOWN;
                    gp2x_event.key.state = SDL_PRESSED;
                    gp2x_event.key.keysym.sym = SDLK_ESCAPE;
                    SDL_PushEvent( &gp2x_event );
                    break;
/*
                case GP2X_BUTTON_CLICK:
                case GP2X_BUTTON_VOLUP:
                case GP2X_BUTTON_VOLDOWN:
*/
                default:
                    break;
            }
            break;
        case SDL_JOYBUTTONUP:
            i_ret = 2;
            switch( e->jbutton.button )
            {
                case GP2X_BUTTON_LEFT:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_LEFT;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_RIGHT:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_RIGHT;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_UP:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_UP;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_DOWN:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_DOWN;
                    SDL_PushEvent( &gp2x_event );
                    break;
/*
                case GP2X_BUTTON_UPLEFT:
                case GP2X_BUTTON_UPRIGHT:
                case GP2X_BUTTON_DOWNLEFT:
                case GP2X_BUTTON_DOWNRIGHT:
                    break;
*/
                case GP2X_BUTTON_L:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_INSERT;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_R:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_RETURN;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_A:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_END;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_B:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_RETURN;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_X:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_PAGEUP;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_Y:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_PAGEDOWN;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_SELECT:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_HOME;
                    SDL_PushEvent( &gp2x_event );
                    break;
                case GP2X_BUTTON_START:
                    gp2x_event.type = SDL_KEYUP;
                    gp2x_event.key.state = SDL_RELEASED;
                    gp2x_event.key.keysym.sym = SDLK_ESCAPE;
                    SDL_PushEvent( &gp2x_event );
                    break;
/*
                case GP2X_BUTTON_CLICK:
                case GP2X_BUTTON_VOLUP:
                case GP2X_BUTTON_VOLDOWN:
*/
                default:
                    break;
            }
            break;
    }

    return i_ret;
}

void GP2X_Exit( void )
{
    chdir( DIR_GP2X );
    execl( DIR_GP2X_MENU, DIR_GP2X_MENU, NULL );
}
